pubspecContent function

String pubspecContent(
  1. String projectName
)

Returns the pubspec.yaml content as a string for the given project name.

The pubspec.yaml content includes project metadata, dependencies, and dev dependencies.

Implementation

String pubspecContent(String projectName) => '''
### THIS FILE IS READ-ONLY. To update project dependencies, use the 'oyda update' command. ###

name: $projectName
description: A new Oyda project.
version: 1.0.0+1

environment:
  sdk: '>=3.4.0 <4.0.0'
  flutter: ">=1.17.0"

dependencies:
  flutter:
    sdk: flutter
  flutter_dotenv: ^5.1.0
  http: ^1.2.1
  oydadb: ^1.0.3

dev_dependencies:
  flutter_test:
    sdk: flutter

flutter:
  uses-material-design: true
  assets:
    - .env

''';