widgetTestContent function

String widgetTestContent(
  1. String projectName
)

Returns the widget test content as a string for the given project name.

The widget test content includes import statements, the main test function, and a test case.

Implementation

String widgetTestContent(String projectName) => '''
import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:oydadb/src/oyda_interface.dart';

void main() async {
  group('OYDAInterface', () {
    test('selectTable', () async {
      await dotenv.load(fileName: ".env");
      var table = await OydaInterface().selectTable('test');
      print(table);

    });
  });

}
''';